# Warning: this package is synchronized with Fedora!

%global libmajor 0
%global girapi 1.0
%global girlib %mklibname %{name}-gir %{girapi}
%global libname %mklibname %{name} %{libmajor}
%global devname %mklibname %{name} -d

# Minimum dependent components
%global appstream_version 1.0.0
%global bubblewrap_version 0.8.0
%global glib_version 2.46.0
%global gpgme_version 1.8.0
%global libcurl_version 7.29.0
%global ostree_version 2020.8
%global wayland_protocols_version 1.32
%global wayland_scanner_version 1.15

%{?!_pkgdocdir:%global _pkgdocdir %{_docdir}/%{name}}

Version:        1.15.8
Release:        %mkrel 2
# (ovitters) this warnings is NOT in Fedora
# If the patch version increases, please rebuild the dependant packages
# See/read the error message for the specifics
%define patch_ver %(echo %{version}|cut -d. -f1,2)
%global patch_ver_dependant 1.15

# This handles printing the error
%if "%patch_ver" != "%patch_ver_dependant"
%{error:%dnl
Make sure to rebuild the packages depending on flatpak: discover, %dnl
%gnome-software and the various portals. To silence this error please increase %dnl
%the patch_ver_dependant to the current minor version (%patch_ver)} %dnl
%endif

Name:           flatpak
Summary:        Application deployment framework for desktop apps

Group:          System/Packaging
License:        LGPLv2+
URL:            https://flatpak.org/
Source0:        https://github.com/flatpak/flatpak/releases/download/%{version}/%{name}-%{version}.tar.xz
Patch0:         flatpak-1.15.2-compile.patch
#
# Security patches
# P100 -> ...
#

BuildRequires:  pkgconfig(appstream) >= %{appstream_version}
BuildRequires:  pkgconfig(dconf)
BuildRequires:  pkgconfig(fuse3)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0) >= %{glib_version}
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.40.0
BuildRequires:  pkgconfig(gpgme) >= %{gpgme_version}
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libarchive) >= 2.8.0
BuildRequires:  pkgconfig(libseccomp)
BuildRequires:  pkgconfig(libcurl) >= %{libcurl_version}
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libxml-2.0) >= 2.4
BuildRequires:  pkgconfig(libzstd) >= 0.8.1
BuildRequires:  pkgconfig(ostree-1) >= %{ostree_version}
BuildRequires:  pkgconfig(polkit-gobject-1)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-protocols) >= %{wayland_protocols_version}
BuildRequires:  pkgconfig(wayland-scanner) >= %{wayland_scanner_version}
BuildRequires:  pkgconfig(xau)
BuildRequires:  pkgconfig(malcontent-0)
BuildRequires:  bison
BuildRequires:  bubblewrap >= %{bubblewrap_version}
BuildRequires:  chrpath
BuildRequires:  docbook-dtds
BuildRequires:  docbook-style-xsl
BuildRequires:  gettext
BuildRequires:  libcap-devel
BuildRequires:  meson
BuildRequires:  python3dist(pyparsing)
BuildRequires:  systemd-devel
BuildRequires:  socat
BuildRequires:  xdg-dbus-proxy
BuildRequires:  xmlto-notex
BuildRequires:  xsltproc
BuildRequires:  selinux-policy-devel

# Needed for the document portal.
Requires:       fuse3

# Needed for confinement
Requires:       bubblewrap%{?_isa} >= %{bubblewrap_version}
Requires:       ostree%{?_isa} >= %{ostree_version}
Requires:       xdg-dbus-proxy%{?_isa}
Recommends:     xdg-desktop-portal > 0.10
Conflicts:      xdg-desktop-portal <= 0.10

# For supporting exporting SVG icons from flatpaks
Requires:       %{mklibname rsvg2 _2}%{?_isa}

# Required to ensure flatpak functions
Requires:       %{libname}%{?_isa} = %{version}-%{release}
Requires:       %{girlib}%{?_isa} = %{version}-%{release}
Requires(pre):  shadow-utils

Recommends:     xdg-desktop-portal

%description
flatpak is a system for building, distributing and running sandboxed desktop
applications on Linux. See https://wiki.gnome.org/Projects/SandboxedApps for
more information.

%package -n %{devname}
Summary:        Development files for %{name}
Group:          Development/C
License:        LGPLv2+
Provides:       %{name}-devel = %{version}-%{release}
Provides:       %{name}-devel%{?_isa} = %{version}-%{release}
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       %{libname}%{?_isa} = %{version}-%{release}
Requires:       %{girlib}%{?_isa} = %{version}-%{release}

%description -n %{devname}
This package contains the pkg-config file and development headers for %{name}.

%package -n %{libname}
Summary:        Libraries for %{name}
Group:          System/Libraries
License:        LGPLv2+
Requires:       bubblewrap%{?_isa} >= %{bubblewrap_version}
Requires:       ostree%{?_isa} >= %{ostree_version}

%description -n %{libname}
This package contains libflatpak.

%package -n %{girlib}
Summary:        GObject Introspection Libraries for %{name}
Group:          System/Libraries
License:        LGPLv2+
Requires:       %{libname}%{?_isa} = %{version}-%{release}

%description -n %{girlib}
This package contains libflatpak GObject libraries.

%package selinux
Summary:        SELinux policy module for %{name}
Group:          System/Libraries
BuildRequires:  selinux-policy-devel
BuildRequires:  make
BuildArch:      noarch
%{?selinux_requires}

%description selinux
This package contains the SELinux policy module for %{name}.

%package session-helper
Summary:        User D-Bus service used by %{name} and others
Group:          System/Libraries
Conflicts:      flatpak < 1.14.4-3
Requires:       systemd

%description session-helper
This package contains the org.freedesktop.Flatpak user D-Bus service
that's used by %{name} and other packages.

%package tests
Summary:        Tests for %{name}
Group:          Development/Other
License:        LGPLv2+
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       %{libname}%{?_isa} = %{version}-%{release}
Requires:       %{girlib}%{?_isa} = %{version}-%{release}
Requires:       bubblewrap >= %{bubblewrap_version}
Requires:       ostree%{?_isa} >= %{ostree_version}

%description tests
This package contains installed tests for %{name}.


%prep
%autosetup -p1

%build
%meson \
    -Dinstalled_tests=true \
    -Dsystem_bubblewrap=%{_bindir}/bwrap \
    -Dsystem_dbus_proxy=%{_bindir}/xdg-dbus-proxy \
    -Dtmpfilesdir=%{_tmpfilesdir} \
    -Dmalcontent=enabled \
    -Dwayland_security_context=enabled \
    %{nil}
%meson_build


%install
%meson_install

install -pm 644 NEWS README.md %{buildroot}/%{_pkgdocdir}
# The system repo is not installed by the flatpak build system.
install -d %{buildroot}%{_localstatedir}/lib/flatpak
install -d %{buildroot}%{_sysconfdir}/flatpak/remotes.d

chrpath -d %{buildroot}%{_libexecdir}/installed-tests/Flatpak/testlibrary

%find_lang %{name}

%pre
getent group flatpak >/dev/null || groupadd -r flatpak
getent passwd flatpak >/dev/null || \
    useradd -r -g flatpak -d / -s /sbin/nologin \
     -c "User for flatpak system helper" flatpak
exit 0


%post
# Create an (empty) system-wide repo.
flatpak remote-list --system &> /dev/null || :

%post selinux
%selinux_modules_install %{_datadir}/selinux/packages/flatpak.pp.bz2

%postun selinux
if [ $1 -eq 0 ]; then
    %selinux_modules_uninstall %{_datadir}/selinux/packages/flatpak.pp.bz2
fi

%files -f %{name}.lang
%license COPYING
%doc %{_pkgdocdir}
%{_bindir}/flatpak
%{_bindir}/flatpak-bisect
%{_bindir}/flatpak-coredumpctl
%{_datadir}/bash-completion
%{_datadir}/dbus-1/interfaces/org.freedesktop.portal.Flatpak.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.Flatpak.Authenticator.xml
%{_datadir}/dbus-1/services/org.flatpak.Authenticator.Oci.service
%{_datadir}/dbus-1/services/org.freedesktop.portal.Flatpak.service
%{_datadir}/dbus-1/system-services/org.freedesktop.Flatpak.SystemHelper.service
%{_datadir}/fish/vendor_conf.d/flatpak.fish
%{_datadir}/fish/vendor_completions.d/flatpak.fish
%{_datadir}/%{name}/
%{_datadir}/polkit-1/actions/org.freedesktop.Flatpak.policy
%{_datadir}/polkit-1/rules.d/org.freedesktop.Flatpak.rules
%{_datadir}/zsh/site-functions
%{_libexecdir}/flatpak-oci-authenticator
%{_libexecdir}/flatpak-portal
%{_libexecdir}/flatpak-system-helper
%{_libexecdir}/flatpak-validate-icon
%{_libexecdir}/revokefs-fuse
%dir %{_localstatedir}/lib/flatpak
%{_mandir}/man1/%{name}*.1*
%{_mandir}/man5/%{name}-metadata.5*
%{_mandir}/man5/flatpakref.5*
%{_mandir}/man5/flatpak-flatpakref.5*
%{_mandir}/man5/flatpakrepo.5*
%{_mandir}/man5/flatpak-flatpakrepo.5*
%{_mandir}/man5/flatpak-installation.5*
%{_mandir}/man5/flatpak-remote.5*
%{_sysconfdir}/dbus-1/system.d/org.freedesktop.Flatpak.SystemHelper.conf
%dir %{_sysconfdir}/flatpak
%{_sysconfdir}/flatpak/remotes.d
%{_sysconfdir}/profile.d/flatpak.sh
%{_sysusersdir}/%{name}.conf
%{_unitdir}/flatpak-system-helper.service
%{_userunitdir}/flatpak-oci-authenticator.service
%{_userunitdir}/flatpak-portal.service
%{_systemd_system_env_generator_dir}/60-flatpak-system-only
%{_systemd_user_env_generator_dir}/60-flatpak
%{_tmpfilesdir}/%{name}.conf

%files -n %{devname}
%{_datadir}/gir-1.0/Flatpak-%{girapi}.gir
%doc %{_datadir}/gtk-doc/html/%{name}/
%{_includedir}/%{name}/
%{_libdir}/libflatpak.so
%{_libdir}/pkgconfig/%{name}.pc

%files -n %{libname}
%license COPYING
%{_libdir}/libflatpak.so.%{libmajor}{,.*}

%files -n %{girlib}
%{_libdir}/girepository-1.0/Flatpak-%{girapi}.typelib

%files selinux
%{_datadir}/selinux/packages/flatpak.pp.bz2
%{_datadir}/selinux/devel/include/contrib/flatpak.if

%files session-helper
%license COPYING
%{_datadir}/dbus-1/interfaces/org.freedesktop.Flatpak.xml
%{_datadir}/dbus-1/services/org.freedesktop.Flatpak.service
%{_libexecdir}/flatpak-session-helper
%{_userunitdir}/flatpak-session-helper.service

%files tests
%{_datadir}/installed-tests
%{_libexecdir}/installed-tests



%changelog
* Sun Mar 16 2025 wally <wally> 1.15.8-2.mga10
+ Revision: 2164785
- rebuild for libxml2 2.13.6

* Mon Jun 17 2024 daviddavid <daviddavid> 1.15.8-1.mga10
+ Revision: 2074665
- new version: 1.15.8, fixes CVE-2024-32462 (mga#33119)

* Tue Feb 06 2024 daviddavid <daviddavid> 1.15.6-1.mga10
+ Revision: 2037733
- new version: 1.15.6
- switch to meson build system
- rebuild for new appstream 1.0.1

* Thu Mar 16 2023 daviddavid <daviddavid> 1.14.4-1.mga9
+ Revision: 1949444
- new version: 1.14.4, fixes CVE-2023-28100 and CVE-2023-28101 (mga#31688)
+ wally <wally>
- switch to use fuse3

* Tue Sep 27 2022 wally <wally> 1.14.0-1.mga9
+ Revision: 1892844
- new version 1.14.0

* Tue Sep 27 2022 wally <wally> 1.12.7-2.mga9
+ Revision: 1892840
- build against libcurl instead of libsoup2

* Fri Apr 01 2022 neoclust <neoclust> 1.12.7-1.mga9
+ Revision: 1839764
- New version 1.12.7

* Sat Oct 16 2021 luigiwalser <luigiwalser> 1.12.2-1.mga9
+ Revision: 1751894
- 1.12.2

* Sat Oct 16 2021 neoclust <neoclust> 1.12.1-1.mga9
+ Revision: 1751872
- New version 1.12.1

* Mon Jul 05 2021 joequant <joequant> 1.11.2-1.mga9
+ Revision: 1734848
- update to 1.11.2
  1.11.2 has much lower cpu usage than v1.10

* Wed Mar 10 2021 neoclust <neoclust> 1.10.2-1.mga9
+ Revision: 1701120
- New version 1.10.2: Fixing security issues (mga#28575)

* Tue Jan 26 2021 neoclust <neoclust> 1.10.1-1.mga8
+ Revision: 1673513
- New version 1.10.1

* Thu Jan 14 2021 tmb <tmb> 1.8.5-1.mga8
+ Revision: 1671803
- update to 1.8.5 (security update)
+ ovitters <ovitters>
- add a double check to ensure packager will rebuild dependant packages

* Tue Aug 18 2020 ovitters <ovitters> 1.8.1-1.mga8
+ Revision: 1614764
- new version 1.8.1

* Sat Feb 29 2020 tv <tv> 1.6.2-1.mga8
+ Revision: 1552342
- 1.6.2

* Sun Feb 16 2020 umeabot <umeabot> 1.4.1-4.mga8
+ Revision: 1532190
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Sep 16 2019 tv <tv> 1.4.1-3.mga8
+ Revision: 1441997
- remove obsolete requires on kernel (thus fixing deps on aarch64)

* Sat Jun 29 2019 ngompa <ngompa> 1.4.1-2.mga8
+ Revision: 1415412
- Fix dependency error in tests subpackage

* Sat Jun 15 2019 ngompa <ngompa> 1.4.1-1.mga7
+ Revision: 1400035
- Rebase to v1.4.1

* Sun Mar 31 2019 shlomif <shlomif> 1.0.8-1.mga7
+ Revision: 1383867
- New version 1.0.8 ; mga#23866 security

* Fri Feb 15 2019 shlomif <shlomif> 1.0.7-1.mga7
+ Revision: 1367456
- New version 1.0.7 to fix CVE-2019-5736 (mga#24355)

* Wed Jan 02 2019 shlomif <shlomif> 1.0.6-1.mga7
+ Revision: 1348729
- New version 1.0.6 ; sync from f29 ; MGA#23866

* Sat Aug 25 2018 ngompa <ngompa> 1.0.0-1.mga7
+ Revision: 1254477
- Update to v1.0.0

* Sun Jul 15 2018 wally <wally> 0.99.3-1.mga7
+ Revision: 1243749
- new version 0.99.3

* Mon Feb 12 2018 ngompa <ngompa> 0.10.3-1.mga7
+ Revision: 1200566
- Update to 0.10.3

* Sun Nov 19 2017 ngompa <ngompa> 0.10.0-1.mga7
+ Revision: 1177835
- Upgrade to 0.10.0

* Mon Sep 18 2017 ngompa <ngompa> 0.9.12-1.mga7
+ Revision: 1155269
- Update to 0.9.12

* Mon Sep 11 2017 ngompa <ngompa> 0.9.10-1.mga7
+ Revision: 1152633
- Rebase to v0.9.10
- Drop flatpak-builder subpackage as it's now a separate project

* Sat Jun 24 2017 ngompa <ngompa> 0.9.6-2.mga6
+ Revision: 1108264
- Update to 0.9.6

* Fri May 26 2017 akien <akien> 0.9.4-2.mga6
+ Revision: 1104770
- Rebuild for armv5tl (buildsystem issue)

* Fri May 26 2017 ngompa <ngompa> 0.9.4-1.mga6
+ Revision: 1104757
- Update to 0.9.4

* Thu Apr 27 2017 ngompa <ngompa> 0.9.3-1.mga6
+ Revision: 1097788
- Update to 0.9.3

* Tue Mar 21 2017 ovitters <ovitters> 0.9.1-1.mga6
+ Revision: 1094194
- new version 0.9.1

* Thu Mar 16 2017 ngompa <ngompa> 0.8.4-1.mga6
+ Revision: 1093163
- Update to 0.8.4

* Fri Feb 17 2017 ngompa <ngompa> 0.8.3-1.mga6
+ Revision: 1086571
- Update to 0.8.3

* Mon Jan 30 2017 ngompa <ngompa> 0.8.2-1.mga6
+ Revision: 1084179
- Upgrade to 0.8.2 (Fixes mga#20208)

* Mon Jan 16 2017 ngompa <ngompa> 0.8.0-1.mga6
+ Revision: 1082044
- Upgrade to v0.8.0

* Tue Dec 13 2016 akien <akien> 0.6.14-2.mga6
+ Revision: 1074451
- Rebuild for updated ostree

* Tue Dec 13 2016 ngompa <ngompa> 0.6.14-1.mga6
+ Revision: 1074438
- Upgrade to 0.6.14

* Sat Nov 12 2016 ngompa <ngompa> 0.6.13-2.mga6
+ Revision: 1066784
- Add empty /etc/flatpak/remotes.d

* Wed Oct 26 2016 ngompa <ngompa> 0.6.13-1.mga6
+ Revision: 1063586
- Upgrade to 0.6.13

* Tue Oct 11 2016 pterjan <pterjan> 0.6.12-2.mga6
+ Revision: 1060194
- Rebuild some recently rejected packages, some were due to a bug in the build system

* Tue Oct 11 2016 ngompa <ngompa> 0.6.12-1.mga6
+ Revision: 1060122
- Upgrade to 0.6.12

* Mon Sep 26 2016 tv <tv> 0.6.11-2.mga6
+ Revision: 1056877
- rebuild with fixed rpm-mageia-setup for missing generating typelib() requires (mga#19454)

* Sun Sep 25 2016 ngompa <ngompa> 0.6.11-1.mga6
+ Revision: 1055953
- Upgrade to 0.6.11
- Set minimum ostree and bubblewrap versions

* Thu Aug 25 2016 ngompa <ngompa> 0.6.9-1.mga6
+ Revision: 1048912
- Update to 0.6.9
- Drop unneeded Obsoletes

* Mon Aug 01 2016 ngompa <ngompa> 0.6.8-1.mga6
+ Revision: 1044203
- Bump libostree BR
- Update to 0.6.8 and unbundle bubblewrap from flatpak

* Sat Jul 02 2016 ngompa <ngompa> 0.6.7-1.mga6
+ Revision: 1038364
- Update to 0.6.7

* Sat Jun 25 2016 ngompa <ngompa> 0.6.6-1.mga6
+ Revision: 1037471
- Upgrade to 0.6.6

* Wed Jun 22 2016 ngompa <ngompa> 0.6.5-2.mga6
+ Revision: 1037222
- Add enforced requires for flatpak libraries

* Tue Jun 21 2016 ngompa <ngompa> 0.6.5-1.mga6
+ Revision: 1037015
- Upgrade to flatpak 0.6.5
- Rename xdg-app to flatpak

* Wed Jan 20 2016 daviddavid <daviddavid> 0.4.4-2.mga6
+ Revision: 926028
- switch to %%configure2_5x to fix build

* Thu Oct 08 2015 ovitters <ovitters> 0.4.4-1.mga6
+ Revision: 887873
- from fedora

